@@ -39,6 +39,7 @@ def get_default_settings():
                 "nxticks": 4,
                 "show_ylabel": True,
                 "show_xlabel": True,
+                "sans_serif": False,
                 "bar_color": "k"}
     return settings
 
@@ -53,11 +54,12 @@ def parse_plot_settings(settings_filename, event=None, chrom=None,
                         # Boolean parameters
                         BOOL_PARAMS=["logged", "show_posteriors", "number_junctions",
                                      "reverse_minus", "bar_posteriors", "show_ylabel",
-                                     "show_xlabel"],
+                                     "show_xlabel", "sans_serif"],
                         # Parameters to be interpreted as Python lists or
                         # data structures
                         DATA_PARAMS=["miso_files", "bam_files", "bf_thresholds",
-                                     "bar_color", "sample_labels"]):
+                                     "bar_color", "sample_labels"],
+                        no_posteriors=False):
     """
     Populate a settings dictionary with the plotting parameters, parsed
     as the right datatype.
@@ -107,7 +109,11 @@ def parse_plot_settings(settings_filename, event=None, chrom=None,
         print "Error: Must provide sample label for each entry in bam_files!"
         sys.exit(1)
 
-    if "miso_prefix" in settings and (event != None and chrom != None):
+    if no_posteriors:
+        settings["show_posteriors"] = False
+
+    if ("miso_prefix" in settings) and (event != None and chrom != None) \
+        and settings["show_posteriors"]:
         miso_files = miso_utils.get_miso_output_files(event, chrom, settings)
     else:
         miso_files = settings["miso_files"]
